using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using MySql.Data;
using MySql.Data.MySqlClient;

public partial class search : System.Web.UI.Page
{
    protected void Page_Load(object sender, System.EventArgs e)
    {
        if (!Page.IsPostBack)
        {

            // When this page loads we retrieve two parameters from the url and place the data in two hidden fields.
            HiddenKeywords.Value = Convert.ToString(Request.QueryString["kw"]);
            HiddenP2.Value = Convert.ToString(Request.QueryString["p2"]);
            HeadLiteral.Text = HiddenKeywords.Value;

            // We select posts from the "content" table where the keyword matches any string of the same sentence
            // in the MetaKeywords field in the "content" table.

            // Declare variables for a connection string and a SELECT statement.
            string ConnString = ConfigurationManager.ConnectionStrings["ConnectionString"].ToString();
            string sql = "SELECT * FROM content WHERE MetaKeywords LIKE @Keywords ORDER BY Name ASC";

            // Create a MySqlConnection. The using block is used to call dispose (close) automatically even if 
            // there are an exception.
            using (MySqlConnection cn = new MySqlConnection(ConnString))
            {
                // Create a MySqlDataAdapter.
                MySqlDataAdapter sad = new MySqlDataAdapter();

                // Create a MySqlCommand.
                MySqlCommand cmd = new MySqlCommand(sql, cn);

                // Create a DataTable.
                DataTable dt = new DataTable();

                // Create a PagedDataSource.
                PagedDataSource objPds = new PagedDataSource();

                // Add parameters.
                cmd.Parameters.AddWithValue("@Keywords", "%" + HiddenKeywords.Value + "%");

                // The Try/Catch/Finally block is used to handle exceptions.
                try
                {
                    // Open the connection.
                    cn.Open();

                    // Set the SelectCommand for the adapter.
                    sad.SelectCommand = cmd;

                    // Fill the DataTable with data.
                    sad.Fill(dt);

                    // Populate the repeater control with the datatable 
                    objPds.DataSource = dt.DefaultView;

                    // Indicate that the data should be paged 
                    objPds.AllowPaging = true;

                    // Set the pagesize 
                    objPds.PageSize = 10;

                    // The current page (curpage) is declared as an integer
                    Int32 curpage = 1;

                    // We set the page number for the current page from the page parameter in the url
                    // or to 1 if there are no page parameter in the url
                    if (Request.QueryString["page"] != null)
                    {
                        curpage = Convert.ToInt32(Request.QueryString["page"]);
                    }
                    else
                    {
                        curpage = 1;
                    }

                    // The current page index is equal to the current page minus 1 and we need to no this
                    // to show the right page to the user.
                    objPds.CurrentPageIndex = curpage - 1;

                    // We set the text in the middle to show the current pagenumber and the last pagenumber
                    lblCurrentPage.Text = "| Page: " + curpage.ToString() + " of " + objPds.PageCount.ToString() + " |";

                    // This is code for the link to the previous page, we don't show this link on the first page
                    if (!objPds.IsFirstPage)
                    {
                        lnkPrev.Visible = true;
                        lnkPrev.NavigateUrl = "~/search.aspx?kw=" + HiddenKeywords.Value + "&" + "page=" + Convert.ToString(curpage - 1);
                    }

                    // This is code for the link to the next page, we don't show this link on the last page
                    if (!objPds.IsLastPage)
                    {
                        lnkNext.Visible = true;
                        lnkNext.NavigateUrl = "~/search.aspx?kw=" + HiddenKeywords.Value + "&" + "page=" + Convert.ToString(curpage + 1);
                    }

                    // This code binds the search result to a repeater control
                    ContentListRepeater.DataSource = objPds;
                    ContentListRepeater.DataBind();

                }
                catch (Exception ex)
                {
                    Response.Write(ex.Message);
                }
                finally
                {
                    // Dispose of objects to avoid memory leakage.
                    sad.Dispose();
                    cmd.Dispose();
                    dt.Dispose();
                }
            }
        }
    }

    protected string GenerateURL(object Contentname)
    {
        //Create SEO Friendly URL for each content link.
        string strConUrl = "~/article/" + Contentname + ".aspx";

        return strConUrl;
    }
}
